betty.extension.nginx.serve module - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.nginx.serve module

Integrate the nginx extension with Betty’s Serve API.

final class betty.extension.nginx.serve.DockerizedNginxServer

  Bases: `Server`

  An nginx server that runs within a Docker container.

  Parameters:

    project (`betty.project.Project`)

  __init__(project: betty.project.Project) → None
    Parameters:

      project (`betty.project.Project`)

  classmethod is_available() → bool

    Check if Docker is available.

    Return type:

      `bool`

  property public_url: str

    The server’s public URL.

  async start() → None

    Start the server.

    Return type:

      `None`

  async stop() → None

    Stop the server.

    Return type:

      `None`